function [sampleLabels, subspaceBases, returnStatus]=rgpca_influence(X, subspaceDimensions, varargin)

FISHER_NULLSPACE = 0;
SVD_NULLSPACE = 1;
METHOD_LEAVE_ONE_OUT = 1;
METHOD_CLOSED_FORM = 0;

% Set default parameter values
outlierPercentage = 0;
angleTolerance = 0.1;
dataNormalization = true;
postOptimization = true;
nullSpaceMethod = FISHER_NULLSPACE;
robustMethod = METHOD_CLOSED_FORM;
classifyMissingSamples = true;

% Parse the optional inputs.
if (mod(length(varargin), 2) ~= 0 ),
    error(['Extra Parameters passed to the function ''' mfilename ''' must be passed in pairs.']);
end
parameterCount = length(varargin)/2;

parameterInitialized = false;
for parameterIndex = 1:parameterCount,
    parameterName = varargin{parameterIndex*2 - 1};
    parameterValue = varargin{parameterIndex*2};
    switch lower(parameterName)
        case 'outlierpercentage'
            outlierPercentage = parameterValue;
            if outlierPercentage<0 || outlierPercentage>=1
                error(['The parameter ''' parameterName ''' is out of range']);
            end
        case 'angletolerance'
            angleTolerance = parameterValue;
            if angleTolerance<0 || angleTolerance>=pi/2
                error(['The parameter ''' parameterName ''' is out of range']);
            end
        case 'datanormalization'
            dataNormalization = parameterValue;
            if dataNormalization~=1 && dataNormalization~=0
                error(['The parameter ''' parameterName ''' is out of range']);
            end
        case 'postoptimization'
            postOptimization = parameterValue;
            if postOptimization~=1 && postOptimization~=0
                error(['The parameter ''' parameterName ''' is out of range']);
            end
        case 'nullspacemethod'
            nullSpaceMethod = parameterValue;
            if nullSpaceMethod~=1 && nullSpaceMethod~=0
                error(['The parameter ''' parameterName ''' is out of range']);
            end
        case 'classifymissingsamples'
            classifyMissingSamples = parameterValue;
            if classifyMissingSamples~=1 && classifyMissingSamples~=0
                error(['The parameter ''' parameterName ''' is out of range']);
            end            
        case 'priority'
            if strcmp(parameterValue,'accuracy')
                robustMethod = METHOD_LEAVE_ONE_OUT;
            elseif ~strcmp(parameterValue,'speed')
                error(['Sorry, the parameter value ''' parameterValue ''' is not recognized by the function ''' mfilename '''.']);
            end
        otherwise
            error(['Sorry, the parameter ''' parameterName ''' is not recognized by the function ''' mfilename '''.']);
    end
end

if robustMethod==METHOD_CLOSED_FORM
    [sampleLabels, subspaceBases, returnStatus] = rgpca_closed_form(X, subspaceDimensions,...
        'outlierPercentage', outlierPercentage, 'postoptimization',postOptimization,'angleTolerance',angleTolerance,...
        'dataNormalization',dataNormalization,'nullspacemethod', nullSpaceMethod, 'classifymissingsamples', classifyMissingSamples);
else
    [sampleLabels, subspaceBases, returnStatus] = rgpca_leave_one_out(X, subspaceDimensions,...
        'outlierPercentage', outlierPercentage, 'postoptimization',postOptimization,'angleTolerance',angleTolerance,...
        'dataNormalization',dataNormalization,'nullspacemethod', nullSpaceMethod, 'classifymissingsamples', classifyMissingSamples);
end